@@ -153,7 +153,7 @@ sub new {
   
   bless $self, $class;
 
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   unless (defined $self->class_name) {
     confess "A class name must be specified";
   }
@@ -165,7 +165,7 @@ sub new {
     $self->output_dir($output_dir);
   }
   else {
-    my $default_output_dir = "SPVM::$basic_type_name";
+    my $default_output_dir = "SPVM::$class_name";
     $default_output_dir =~ s/::/-/g;
     $self->output_dir($default_output_dir);
   }
@@ -246,7 +246,7 @@ sub generate_dir {
 sub generate_spvm_class_file {
   my ($self) = @_;
   
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
   # User name
   my $user_name = $self->user_name;
@@ -275,13 +275,13 @@ sub generate_spvm_class_file {
 # Copyright (c) $year $user_name
 # MIT License
 
-class $basic_type_name ${attributes}{
+class $class_name ${attributes}{
   $version_decl
 }
 EOS
   
   # Generate file
-  my $spvm_class_rel_file = SPVM::Builder::Util::convert_basic_type_name_to_rel_file($basic_type_name, 'spvm');
+  my $spvm_class_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file($class_name, 'spvm');
   my $lib_dir = $self->lib_dir;
   $spvm_class_rel_file = $self->create_lib_rel_file($spvm_class_rel_file);
   $self->generate_file($spvm_class_rel_file, $spvm_class_content);
@@ -290,7 +290,7 @@ EOS
 sub generate_perl_class_file {
   my ($self) = @_;
   
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
   # Year
   my $year = $self->_year;
@@ -314,11 +314,11 @@ sub generate_perl_class_file {
   my $description;
   my $main_doc;
   if ($interface) {
-    $description = "The $basic_type_name interface in L<SPVM> has interface methods to do someting.";
+    $description = "The $class_name interface in L<SPVM> has interface methods to do someting.";
     $main_doc  = <<"EOS";
 =head1 Usage
 
-  interface $basic_type_name;
+  interface $class_name;
 
 =head1 Details
 
@@ -331,7 +331,7 @@ sub generate_perl_class_file {
 EOS
   }
   elsif ($resource) {
-    $description = "The $basic_type_name resource in L<SPVM> is a L<resouce|SPVM::Document::Resource> to do someting.";
+    $description = "The $class_name resource in L<SPVM> is a L<resouce|SPVM::Document::Resource> to do someting.";
     
     my $native = $self->native;
     my $new_method;
@@ -371,7 +371,7 @@ MyClass.config:
   
   my \$config = SPVM::Builder::Config->$new_method(file => __FILE__);
   
-  \$config->use_resource('$basic_type_name');
+  \$config->use_resource('$class_name');
   
   \$config;
 
@@ -454,11 +454,11 @@ MyClass.$native_module_ext:
 EOS
   }
   else {
-    $description = "The $basic_type_name class in L<SPVM> has methods to do someting.";
+    $description = "The $class_name class in L<SPVM> has methods to do someting.";
     $main_doc  = <<"EOS";
 =head1 Usage
 
-  use $basic_type_name;
+  use $class_name;
 
 =head1 Details
 
@@ -497,7 +497,7 @@ EOS
   # Content
   my $perl_class_content = "";
   $perl_class_content = <<"EOS";
-package SPVM::$basic_type_name;
+package SPVM::$class_name;
 
 $version_decl
 
@@ -505,7 +505,7 @@ $version_decl
 
 =head1 Name
 
-SPVM::$basic_type_name - Short Description
+SPVM::$class_name - Short Description
 
 =head1 Description
 
@@ -529,7 +529,7 @@ MIT License
 EOS
 
   # Generate file
-  my $perl_class_rel_file = SPVM::Builder::Util::convert_basic_type_name_to_rel_file($basic_type_name, 'pm');
+  my $perl_class_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file($class_name, 'pm');
   $perl_class_rel_file =  $self->create_lib_rel_file($perl_class_rel_file);
   $self->generate_file($perl_class_rel_file, $perl_class_content);
 }
@@ -537,7 +537,7 @@ EOS
 sub generate_native_config_file {
   my ($self) = @_;
   
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
   # C or C++
   my $native = $self->native;
@@ -573,7 +573,7 @@ my \$config = SPVM::Builder::Config->$new_method(file => __FILE__);
 EOS
 
   # Generate file
-  my $native_config_rel_file = SPVM::Builder::Util::convert_basic_type_name_to_rel_file($basic_type_name, 'config');
+  my $native_config_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file($class_name, 'config');
   $native_config_rel_file =  $self->create_lib_rel_file($native_config_rel_file);
   $self->generate_file($native_config_rel_file, $native_config_content);
 }
@@ -581,7 +581,7 @@ EOS
 sub generate_native_class_file {
   my ($self) = @_;
 
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
   # extern C for C++
   my $native = $self->native;
@@ -608,9 +608,9 @@ sub generate_native_class_file {
   }
   
   # Content
-  my $native_basic_type_name = $basic_type_name;
-  $native_basic_type_name =~ s/::/__/g;
-  my $native_class_file = $basic_type_name;
+  my $native_class_name = $class_name;
+  $native_class_name =~ s/::/__/g;
+  my $native_class_file = $class_name;
   $native_class_file =~ s/::/\//g;
   $native_class_file .= ".$native_module_ext";
 
@@ -633,7 +633,7 @@ $extern_c_start
 
 static const char* FILE_NAME = "$native_class_file";
 
-int32_t SPVM__${native_basic_type_name}__foo(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__${native_class_name}__foo(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   return 0;
 }
@@ -641,7 +641,7 @@ int32_t SPVM__${native_basic_type_name}__foo(SPVM_ENV* env, SPVM_VALUE* stack) {
 $extern_c_end
 EOS
   
-  my $native_class_rel_file = SPVM::Builder::Util::convert_basic_type_name_to_rel_file($basic_type_name, $native_module_ext);
+  my $native_class_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file($class_name, $native_module_ext);
   $native_class_rel_file =  $self->create_lib_rel_file($native_class_rel_file);
   $self->generate_file($native_class_rel_file, $native_class_content);
 }
@@ -649,10 +649,10 @@ EOS
 sub generate_gitkeep_file_for_native_module_include_dir {
   my ($self) = @_;
 
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
   # Generate file
-  my $gitkeep_rel_file_for_native_module_include_dir = SPVM::Builder::Util::convert_basic_type_name_to_rel_file($basic_type_name, 'native');
+  my $gitkeep_rel_file_for_native_module_include_dir = SPVM::Builder::Util::convert_class_name_to_rel_file($class_name, 'native');
   $gitkeep_rel_file_for_native_module_include_dir .= '/include/.gitkeep';
   $gitkeep_rel_file_for_native_module_include_dir =  $self->create_lib_rel_file($gitkeep_rel_file_for_native_module_include_dir);
   $self->generate_file($gitkeep_rel_file_for_native_module_include_dir, '');
@@ -661,10 +661,10 @@ sub generate_gitkeep_file_for_native_module_include_dir {
 sub generate_gitkeep_file_for_native_module_src_dir {
   my ($self) = @_;
 
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
   # Generate file
-  my $gitkeep_rel_file_for_native_module_include_dir = SPVM::Builder::Util::convert_basic_type_name_to_rel_file($basic_type_name, 'native');
+  my $gitkeep_rel_file_for_native_module_include_dir = SPVM::Builder::Util::convert_class_name_to_rel_file($class_name, 'native');
   $gitkeep_rel_file_for_native_module_include_dir .= '/src/.gitkeep';
   $gitkeep_rel_file_for_native_module_include_dir =  $self->create_lib_rel_file($gitkeep_rel_file_for_native_module_include_dir);
   $self->generate_file($gitkeep_rel_file_for_native_module_include_dir, '');
@@ -750,13 +750,13 @@ EOS
 sub generate_readme_markdown_file {
   my ($self) = @_;
   
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
   # Content
   my $readme_markdown_content = <<"EOS";
-# SPVM::$basic_type_name
+# SPVM::$class_name
 
-<a href="https://metacpan.org/pod/SPVM::$basic_type_name">SPVM::$basic_type_name</a>
+<a href="https://metacpan.org/pod/SPVM::$class_name">SPVM::$class_name</a>
 
 EOS
   
@@ -768,21 +768,21 @@ EOS
 sub generate_makefile_pl_file {
   my ($self) = @_;
   
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
   # Resource
   my $resource = $self->resource;
   
   # Native make rule
-  my $make_rule_native = $self->native && !$resource ? "\$make_rule .= SPVM::Builder::Util::API::create_make_rule_native('$basic_type_name');" : '';
+  my $make_rule_native = $self->native && !$resource ? "\$make_rule .= SPVM::Builder::Util::API::create_make_rule_native('$class_name');" : '';
   
   # Precompile make rule
-  my $make_rule_precompile = $self->precompile && !$resource ? "\$make_rule .= SPVM::Builder::Util::API::create_make_rule_precompile('$basic_type_name');" : '';
+  my $make_rule_precompile = $self->precompile && !$resource ? "\$make_rule .= SPVM::Builder::Util::API::create_make_rule_precompile('$class_name');" : '';
 
-  my $perl_class_rel_file = SPVM::Builder::Util::convert_basic_type_name_to_rel_file($basic_type_name, 'pm');
+  my $perl_class_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file($class_name, 'pm');
   $perl_class_rel_file =  $self->create_lib_rel_file($perl_class_rel_file);
 
-  my $spvm_class_rel_file = SPVM::Builder::Util::convert_basic_type_name_to_rel_file($basic_type_name, 'spvm');
+  my $spvm_class_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file($class_name, 'spvm');
   $spvm_class_rel_file =  $self->create_lib_rel_file($spvm_class_rel_file);
   
   # User name
@@ -821,7 +821,7 @@ unless (\$meta) {
 
 my \%configure_and_runtime_requires = ('SPVM' => '$SPVM::VERSION');
 WriteMakefile(
-  NAME => 'SPVM::$basic_type_name',
+  NAME => 'SPVM::$class_name',
   VERSION_FROM => '$perl_class_rel_file',
   LICENSE => 'mit',
   (\$] >= 5.005 ?
@@ -861,6 +861,8 @@ sub MY::postamble {
   unless (\$no_build_spvm_modules) {
     require SPVM::Builder::Util::API;
     
+    local \@INC = ('lib', \@INC);
+    
     $make_rule_native
     $make_rule_precompile
   }
@@ -879,9 +881,9 @@ EOS
 sub generate_basic_test_file {
   my ($self) = @_;
   
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
-  my $spvm_class_rel_file = SPVM::Builder::Util::convert_basic_type_name_to_rel_file($basic_type_name, 'spvm');
+  my $spvm_class_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file($class_name, 'spvm');
   $spvm_class_rel_file =  $self->create_lib_rel_file($spvm_class_rel_file);
   
   # Content
@@ -894,22 +896,22 @@ use FindBin;
 use lib "\$FindBin::Bin/lib";
 BEGIN { \$ENV{SPVM_BUILD_DIR} = "\$FindBin::Bin/.spvm_build"; }
 
-use SPVM 'TestCase::$basic_type_name';
+use SPVM 'TestCase::$class_name';
 
-use SPVM '$basic_type_name';
-use SPVM::$basic_type_name;
+use SPVM '$class_name';
+use SPVM::$class_name;
 use SPVM 'Fn';
 
 my \$api = SPVM::api();
 
 my \$start_memory_blocks_count = \$api->get_memory_blocks_count;
 
-ok(SPVM::TestCase::$basic_type_name->test);
+ok(SPVM::TestCase::$class_name->test);
 
 # Version check
 {
-  my \$version_string = SPVM::Fn->get_version_string("$basic_type_name");
-  is(\$SPVM::${basic_type_name}::VERSION, \$version_string);
+  my \$version_string = SPVM::Fn->get_version_string("$class_name");
+  is(\$SPVM::${class_name}::VERSION, \$version_string);
 }
 
 my \$end_memory_blocks_count = \$api->get_memory_blocks_count;
@@ -926,7 +928,7 @@ EOS
 sub generate_license_file {
   my ($self) = @_;
   
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
   # User name
   my $user_name = $self->user_name;
@@ -970,7 +972,7 @@ EOS
 sub generate_basic_test_spvm_class_file {
   my ($self) = @_;
   
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
   # Resource
   my $resource = $self->resource;
@@ -980,15 +982,15 @@ sub generate_basic_test_spvm_class_file {
   
   if ($resource) {
     $basic_test_spvm_class_content = <<"EOS";
-class TestCase::$basic_type_name {
+class TestCase::$class_name {
   native static method test : int ();
 }
 EOS
   }
   else {
     $basic_test_spvm_class_content = <<"EOS";
-class TestCase::$basic_type_name {
-  use $basic_type_name;
+class TestCase::$class_name {
+  use $class_name;
   static method test : int () {
     
     return 1;
@@ -998,7 +1000,7 @@ EOS
   }
   
   # Generate file
-  my $basic_test_spvm_class_rel_file = SPVM::Builder::Util::convert_basic_type_name_to_rel_file("TestCase::$basic_type_name", 'spvm');
+  my $basic_test_spvm_class_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file("TestCase::$class_name", 'spvm');
   $basic_test_spvm_class_rel_file = "t/lib/$basic_test_spvm_class_rel_file";
   $self->generate_file($basic_test_spvm_class_rel_file, $basic_test_spvm_class_content);
 }
@@ -1006,7 +1008,7 @@ EOS
 sub generate_basic_test_native_config_file {
   my ($self) = @_;
   
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
   # Resource
   my $resource = $self->resource;
@@ -1028,13 +1030,13 @@ use warnings;
 
 my \$config = SPVM::Builder::Config->$new_method(file => __FILE__);
 
-\$config->use_resource('$basic_type_name');
+\$config->use_resource('$class_name');
 
 \$config;
 EOS
   
   # Generate file
-  my $basic_test_native_config_rel_file = SPVM::Builder::Util::convert_basic_type_name_to_rel_file("TestCase::$basic_type_name", 'config');
+  my $basic_test_native_config_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file("TestCase::$class_name", 'config');
   $basic_test_native_config_rel_file = "t/lib/$basic_test_native_config_rel_file";
   $self->generate_file($basic_test_native_config_rel_file, $basic_test_native_config_content);
 }
@@ -1042,7 +1044,7 @@ EOS
 sub generate_basic_test_native_class_file {
   my ($self) = @_;
   
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
   # Resource
   my $resource = $self->resource;
@@ -1061,14 +1063,14 @@ sub generate_basic_test_native_class_file {
   }
   
   # Content
-  my $native_basic_type_name = $basic_type_name;
-  $native_basic_type_name =~ s/::/__/g;
+  my $native_class_name = $class_name;
+  $native_class_name =~ s/::/__/g;
   my $basic_test_native_class_content = <<"EOS";
 #include "spvm_native.h"
 
 $extern_c_start
 
-int32_t SPVM__TestCase__${native_basic_type_name}__test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__TestCase__${native_class_name}__test(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   stack[0].ival = 1;
   
@@ -1088,7 +1090,7 @@ EOS
       $native_module_ext = 'cpp';
     }
   }
-  my $basic_test_native_class_rel_file = SPVM::Builder::Util::convert_basic_type_name_to_rel_file("TestCase::$basic_type_name", $native_module_ext);
+  my $basic_test_native_class_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file("TestCase::$class_name", $native_module_ext);
   $basic_test_native_class_rel_file = "t/lib/$basic_test_native_class_rel_file";
   $self->generate_file($basic_test_native_class_rel_file, $basic_test_native_class_content);
 }
@@ -1096,13 +1098,13 @@ EOS
 sub generate_dist {
   my ($self) = @_;
   
-  my $basic_type_name = $self->class_name;
+  my $class_name = $self->class_name;
   
-  unless (length $basic_type_name) {
+  unless (length $class_name) {
     confess "The class name must be specified";
   }
   
-  if ($basic_type_name =~ /-/) {
+  if ($class_name =~ /-/) {
     confess "The class name cannnot contain \"-\"";
   }
   
@@ -1114,8 +1116,8 @@ sub generate_dist {
     die "The --interface option and the --resource option cannot be specified at the same time"
   }
   
-  my $basic_type_name_rel_file = $basic_type_name;
-  $basic_type_name_rel_file =~ s|::|/|g;
+  my $class_name_rel_file = $class_name;
+  $class_name_rel_file =~ s|::|/|g;
   
   # Generate output directory
   my $output_dir = $self->output_dir;
