@@ -6,7 +6,7 @@ SPVM::Document::Resource - How to write the resource class
 
 A resource is a L<native class|SPVM::Document::NativeClass> that contains a set of sources and headers of native language such as the C language or C<C++>.
 
-A resource doesn't has the native module file such as C<Foo.c>. It has a config file such as C<Foo.config>. Header files are placed at C<Foo.native/include>. Source filies are placed at C<Foo.native/src>. 
+A resource doesn't has the native class file such as C<Foo.c>. It has a config file such as C<Foo.config>. Header files are placed at C<Foo.native/include>. Source filies are placed at C<Foo.native/src>. 
 
 Let's see the files of L<Resource::Zlib|SPVM::Resource::Zlib> as an example.
 
@@ -16,7 +16,7 @@ B<SPVM/Resource/Zlib/V1_2_11.config>
   use warnings;
    
   use SPVM::Builder::Config;
-  my $config = SPVM::Builder::Config->new_c99(file => __FILE__);
+  my $config = SPVM::Builder::Config->new_gnu99(file => __FILE__);
    
   # C souce files
   my @source_files = qw(
@@ -119,7 +119,7 @@ B<lib/SPVM/MyZlib.config>
   use strict;
   use warnings;
   
-  my $config = SPVM::Builder::Config->new_c99(file => __FILE__);
+  my $config = SPVM::Builder::Config->new_gnu99(file => __FILE__);
   
   $config->use_resource('Resource::Zlib');
   
